@@ -38,6 +38,7 @@
     clippy::fallible_impl_from,
     clippy::float_cmp_const,
     clippy::fn_to_numeric_cast,
+    clippy::fn_to_numeric_cast_any,
     clippy::get_unwrap,
     clippy::if_then_some_else_none,
     clippy::imprecise_flops,
@@ -63,11 +64,14 @@
     clippy::str_to_string,
     clippy::string_add,
     clippy::string_lit_as_bytes,
+    clippy::string_slice,
     clippy::string_to_string,
     clippy::suboptimal_flops,
     clippy::suspicious_operation_groupings,
     clippy::todo,
+    clippy::trailing_empty_array,
     clippy::trivial_regex,
+    clippy::undocumented_unsafe_blocks,
     clippy::unimplemented,
     clippy::unnecessary_self_imports,
     clippy::unneeded_field_pattern,
@@ -101,6 +105,17 @@ mod world_init;
 
 use proc_macro::TokenStream;
 
+// TODO: Remove once tests run without complains about it.
+#[cfg(test)]
+mod actually_used_crates_in_tests {
+    use async_trait as _;
+    use cucumber as _;
+    use derive_more as _;
+    use futures as _;
+    use tempfile as _;
+    use tokio as _;
+}
+
 /// Helper macro for generating public shims for [`macro@given`], [`macro@when`]
 /// and [`macro@then`] attributes.
 macro_rules! step_attribute {
